# Quisk Software Defined Radio by N2ADR
**December 27, 2023**

This is Quisk, a Software Defined Radio (SDR).
You supply radio hardware such as Hermes Lite2 or SoftRock to convert
the antenna voltage to I/Q samples.
Then send the samples to a computer running Quisk.
The Quisk software will read the I/Q data, tune it, filter it,
demodulate it, and send the audio to headphones or speakers.
Quisk has a microphone input and a key input so it can operate as a
complete transceiver.

The web page for this project is  [https://groups.io/g/n2adr-sdr](https://groups.io/g/n2adr-sdr).

The change log is [here](CHANGELOG.txt).

Installation instructions are [here](http://james.ahlstrom.name/quisk/docs.html#Installation).

The documentation is [here](http://james.ahlstrom.name/quisk/docs.html).

The help file is [here](http://james.ahlstrom.name/quisk/help.html).
